@@ -4,6 +4,7 @@ use std::{
 };
 
 use crate::sysfs::SysFS;
+use serde::Serialize;
 
 /// Reprepesents a hardware monitor.
 /// Hardware monitors are used to report real-time information about the device, such as temperatures and power usage.
@@ -158,7 +159,7 @@ impl SysFS for HwMon {
     }
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Serialize)]
 pub struct Temperature {
     pub current: Option<f32>,
     pub crit: Option<f32>,
@@ -171,6 +172,7 @@ pub enum HwMonError {
     InvalidValue,
 }
 
+#[derive(Clone, Serialize)]
 pub enum FanControlMethod {
     None,
     Auto,
